# Polars utils module

::: iso_week_date.polars_utils.datetime_to_isoweek
    options:
        show_root_full_path: false
        show_root_heading: true

::: iso_week_date.polars_utils.isoweek_to_datetime
    options:
        show_root_full_path: false
        show_root_heading: true

::: iso_week_date.polars_utils.is_isoweek_series
    options:
        show_root_full_path: false
        show_root_heading: true
